Riverbed SteelScript for SteelCentral AppResponse
=================================================

This package provides device specific bindings for interacting
with Riverbed SteelCentral AppResponse devices as part of the Riverbed
SteelScript for Python.

For a complete guide to installation, see:

  `https://support.riverbed.com/apis/steelscript/index.html <https://support.riverbed.com/apis/steelscript/index.html>`_

License
=======

Copyright (c) 2017 Riverbed Technology, Inc.

This software is licensed under the terms and conditions of the MIT License
accompanying the software ("License").  This software is distributed "AS IS" as
set forth in the License.
